## rgb.py test for RGB LED
## Tomas Krejci [Njord]

import sys
import uasyncio
import machine
import uasyncio as asyncio
from machine import Pin, PWM


class RGB:
    # rgb_pwr = 1.0
    def __init__(self):
        global rgb_pwr
        rgb_pwr = 1.0  # 0.0 - 1.0

        self.led_r = PWM(Pin(22), 100)
        self.led_g = PWM(Pin(26), 100)
        self.led_b = PWM(Pin(27), 100)

    async def set(self, r, g, b):
        global rgb_pwr
        self.led_r.duty_u16(int(65535 * r * rgb_pwr))
        self.led_g.duty_u16(int(65535 * g * rgb_pwr))
        self.led_b.duty_u16(int(65535 * b * rgb_pwr))
        await uasyncio.sleep(0.01)

    async def on(self):
        await self.set(0.8, 0.8, 0.8)

    async def off(self):
        await self.set(0, 0, 0)

    async def set_pwr(self, pwr):
        global rgb_pwr
        rgb_pwr = pwr

    async def get_pwr(self):
        global rgb_pwr
        return rgb_pwr

    async def set_pwr_up(self):
        await self.set_pwr(await self.get_pwr() * 5.0)

    async def set_pwr_down(self):
        await self.set_pwr((await self.get_pwr()) * 0.2)

    async def set_red(self):
        await self.set(1, 0, 0)

    async def set_green(self):
        await self.set(0, 1, 0)

    async def set_blue(self):
        await self.set(0, 0, 1)

    async def set_yellow(self):
        await self.set(1, 1, 0)

    async def set_magenta(self):
        await self.set(1, 0, 1)

    async def set_cyan(self):
        await self.set(0, 1, 1)

    async def set_white(self):
        await self.set(0.8, 0.8, 0.8)

    async def set_orange(self):
        await self.set(1, 0.5, 0)

    async def test(self):
        sec = 1
        print("RGB demo")
        print("Press Ctrl-C to exit")
        await uasyncio.sleep(sec)
        print(f"RGB power: {await self.get_pwr()}")
        print("RGB initializing...")

        await uasyncio.sleep(sec)
        while True:
            print("RGB off")
            await self.off()
            await uasyncio.sleep(sec)
            print("Red on")
            await self.set(1, 0, 0)
            await uasyncio.sleep(sec)
            print("Green on")
            await self.set_green()
            await uasyncio.sleep(sec)
            print("Blue on")
            await self.set_blue()
            await uasyncio.sleep(sec)
            print("White on")
            await self.set_white()
            await uasyncio.sleep(sec)
            print("Red on")
            await self.set_red()
            await uasyncio.sleep(sec)
            print("RGB power down")
            await self.set_pwr_down()
            await self.set_red()
            print("RGB power:", await self.get_pwr())
            await uasyncio.sleep(sec)
            print("RGB power up")
            await self.set_pwr_up()
            await self.set_red()
            print("RGB power:", await self.get_pwr())
            await uasyncio.sleep(sec)


#  test
# rgb = RGB()
# asyncio.run(rgb.test())
